@@ -3,7 +3,7 @@
 #' @param df df
 #' @param group group
 #' @param by by
-#' @import data.table
+#' @note polars is suggested for better performance
 #' @returns A logical value.
 #' @noRd 
 did_multiplegt_dyn_by_check <- function(
@@ -12,7 +12,9 @@ did_multiplegt_dyn_by_check <- function(
     by
 ) {
     sd_by <- NULL
-    df <- data.table(df)
-    df[, sd_by := sd(get(by), na.rm = TRUE), by = c(group)]
+    df <- as.data.frame(df)
+    sd_agg <- aggregate(df[[by]], by = list(grp = df[[group]]), FUN = sd, na.rm = TRUE)
+    names(sd_agg)[2] <- "sd_by"
+    df <- merge(df, sd_agg, by.x = group, by.y = "grp", all.x = TRUE)
     return(mean(df$sd_by, na.rm = TRUE) == 0)
 }
\ No newline at end of file
