@@ -17,6 +17,10 @@ did_multiplegt_dyn_dfs <- function(
 
     # Inherited Globals #
     df <- data$df
+    # Convert polars DataFrame to R data.frame for base R operations
+    if (inherits(df, "polars_data_frame")) {
+      df <- as.data.frame(df)
+    }
     T_max_XX <- data$T_max_XX
 
     tot_s <- NULL
